#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const fs_1 = __importDefault(require("fs"));
const chalk_1 = __importDefault(require("chalk"));
const getFilesFromInput_1 = require("./getFilesFromInput");
const analyzeFile_1 = require("./analyzeFile");
const printDiagnostics_1 = require("./printDiagnostics");
const getStats_1 = require("./getStats");
const { version } = require("../package.json");
commander_1.program
    .description("An application to lint your TODO comments")
    .version(version)
    .argument("<file|dir|glob...>", "Files to check for comments")
    .action(async (input) => {
    var _a, _b;
    const [error, files] = await (0, getFilesFromInput_1.getFilesFromInput)(input);
    if (error) {
        console.error(error.message);
        process.exit(1);
    }
    if (!files) {
        console.error("No files found.");
        process.exit(1);
    }
    const stats = {
        errors: 0,
        warnings: 0,
    };
    const currentDirectory = process.cwd();
    // Read project package.json
    const packageJsonPath = `${currentDirectory}/package.json`;
    if (!fs_1.default.existsSync(packageJsonPath)) {
        console.error(`"package.json" not found. Make sure to run this command from the root folder of your project.`);
        process.exit(1);
    }
    const packageJson = JSON.parse(fs_1.default.readFileSync(packageJsonPath, "utf8"));
    // Read project tsconfig.json
    const tsconfigJsonPath = `${currentDirectory}/tsconfig.json`;
    if (!fs_1.default.existsSync(tsconfigJsonPath)) {
        console.error(`"tsconfig.json" not found. Make sure to run this command from the root folder of a TypeScript project.`);
        process.exit(1);
    }
    const tsconfigJson = JSON.parse(fs_1.default.readFileSync(tsconfigJsonPath, "utf8"));
    const config = (_b = (_a = tsconfigJson === null || tsconfigJson === void 0 ? void 0 : tsconfigJson.compilerOptions) === null || _a === void 0 ? void 0 : _a.plugins) === null || _b === void 0 ? void 0 : _b.find((plugin) => plugin.name === "typescript-todo-or-die-plugin");
    const options = config === null || config === void 0 ? void 0 : config.options;
    const additionalKeywords = (config === null || config === void 0 ? void 0 : config.additionalKeywords) || [];
    files.forEach((file) => {
        const doc = fs_1.default.readFileSync(file, { encoding: "utf-8" });
        const diagnostics = (0, analyzeFile_1.analyzeFile)(doc, {
            keywords: ["TODO", "FIXME", ...additionalKeywords],
            packageJson,
            options,
        });
        if (diagnostics.length === 0) {
            return;
        }
        const { errors, warnings } = (0, getStats_1.getStats)(diagnostics);
        stats.errors += errors;
        stats.warnings += warnings;
        (0, printDiagnostics_1.printDiagnostics)(diagnostics, file);
    });
    const statsText = `${stats.errors + stats.warnings} problems (${stats.errors} errors, ${stats.warnings} warnings)`;
    if (stats.errors > 0) {
        console.log(chalk_1.default.red.bold(statsText));
    }
    else if (stats.warnings > 0) {
        console.log(chalk_1.default.yellow.bold(statsText));
    }
    else {
        console.log(chalk_1.default.green.bold("No unfinished TODO's. Well done!"));
    }
    if (stats.errors > 0) {
        process.exit(1);
    }
    if (process.env.CI && stats.warnings > 0) {
        process.exit(1);
    }
})
    .parse(process.argv);
//# sourceMappingURL=cli.js.map